summaryrefslogtreecommitdiffstats
path: root/librss/article.h
diff options
context:
space:
mode:
Diffstat (limited to 'librss/article.h')
-rw-r--r--librss/article.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/librss/article.h b/librss/article.h
index 0444e7f3..838e2f16 100644
--- a/librss/article.h
+++ b/librss/article.h
@@ -126,7 +126,7 @@ namespace RSS
const TQDateTime &pubDate() const;
/**
* @param tqparent The tqparent widget for the KURLLabel.
* @param name A name for the widget which will be used internally.
* @return a widget (a KURLLabel in this case) for the Article.
* This makes building a user-interface which contains the
@@ -139,7 +139,7 @@ namespace RSS
* Note that you have to delete the KURLLabel object returned by
* this method yourself.
*/
- KURLLabel *widget(TQWidget *tqparent = 0, const char *name = 0) const;
+ KURLLabel *widget(TQWidget *parent = 0, const char *name = 0) const;
private:
struct Private;
@@ -126,7 +126,7 @@ namespace RSS
const TQDateTime &pubDate() const;
/**
- * @param tqparent The tqparent widget for the KURLLabel.
+ * @param parent The parent widget for the KURLLabel.
* @param name A name for the widget which will be used internally.
* @return a widget (a KURLLabel in this case) for the Article.